@@ -156,7 +156,9 @@ def add_certificates(acm_tpl, certs):
         cert_template = initialize_acm_stack_template(resource_name)
         acm_tpl.add_resource(
             ComposeXStack(
-                resource_name, stack_template=cert_template, Parameters=cert_params,
+                resource_name,
+                stack_template=cert_template,
+                Parameters=cert_params,
             )
         )
 
@@ -177,9 +179,9 @@ def create_acm_template(settings):
     return root_acm_tpl
 
 
-class XResource(ComposeXStack):
+class XStack(ComposeXStack):
     """
-    XResource for ComposeX
+    XStack for ComposeX
     """
 
     def __init__(self, title, settings, **kwargs):
