@@ -19,23 +19,18 @@
 Module for the ComposeXSettings class
 """
 
-import re
-from os import environ
+from copy import deepcopy
 from datetime import datetime as dt
 from json import dumps
-from copy import deepcopy
-import yaml
 
-try:
-    from yaml import CDumper as Dumper
-except ImportError:
-    from yaml import Dumper
+import yaml
 
 import boto3
 from botocore.exceptions import ClientError
 
 from ecs_composex import __version__
 from ecs_composex.common import keyisset, LOG, load_composex_file
+from ecs_composex.common.envsubst import expandvars
 from ecs_composex.common.aws import get_account_id, get_region_azs
 from ecs_composex.common.cfn_params import USE_FLEET_T
 from ecs_composex.utils.init_ecs import set_ecs_settings
@@ -43,6 +38,7 @@ from ecs_composex.utils.init_s3 import create_bucket
 from ecs_composex.ecs.ecs_service_config import set_service_ports
 from cfn_flip.yaml_dumper import LongCleanDumper
 from ecs_composex.secrets.secrets_config import parse_secrets
+from ecs_composex.common.compose_resources import Service
 
 
 def render_services_ports(services):
@@ -78,23 +74,6 @@ def merge_ports(source_ports, new_ports):
     return new_ports
 
 
-def parse_environment_variables(key):
-    """
-    Method to go over the content and interpolate possibly existing environment variables.
-
-    :param str key: the key to find the value for in environment
-    :return: env_key
-    :rtype: str
-    :raises: EnvironmentError
-    """
-    strip_re = re.compile(r"([^\${}]+)")
-    env_key = strip_re.findall(key)[0]
-    LOG.debug(f"Key {key} gives {env_key}")
-    if environ.get(env_key):
-        return environ.get(env_key)
-    raise EnvironmentError(f"Key {key} not found in environment variables.")
-
-
 def merge_service_definition(original_def, override_def, nested=False):
     """
     Merges two services definitions if service exists in both compose files.
@@ -143,14 +122,19 @@ def interpolate_env_vars(content):
     :param dict content:
     :return:
     """
-    env_var_regex = re.compile(r"^\$\{[\w\d-]+\}$")
     if not content:
         return
     for key in content.keys():
         if isinstance(content[key], dict):
             interpolate_env_vars(content[key])
-        elif isinstance(content[key], str) and env_var_regex.match(content[key]):
-            content[key] = parse_environment_variables(content[key])
+        elif isinstance(content[key], list):
+            for count, item in enumerate(content[key]):
+                if isinstance(item, dict):
+                    interpolate_env_vars(item)
+                elif isinstance(item, str):
+                    content[key][count] = expandvars(item)
+        elif isinstance(content[key], str):
+            content[key] = expandvars(content[key])
 
 
 def merge_config_file(original_content, override_content):
@@ -306,6 +290,18 @@ class ComposeXSettings(object):
             indent=4,
         )
 
+    def set_services(self):
+        """
+        Method to define the ComposeXResource for each service.
+        :return:
+        """
+        if not keyisset("services", self.compose_content):
+            return
+        for service_name in self.compose_content["services"]:
+            self.compose_content["services"][service_name] = Service(
+                service_name, self.compose_content["services"][service_name]
+            )
+
     def set_content(self, kwargs, content=None):
         """
         Method to initialize the compose content
@@ -331,6 +327,7 @@ class ComposeXSettings(object):
         LOG.debug(yaml.dump(self.compose_content))
         interpolate_env_vars(self.compose_content)
         parse_secrets(self)
+        self.set_services()
 
     def parse_command(self, kwargs, content=None):
         """
@@ -424,7 +421,7 @@ class ComposeXSettings(object):
                 if code == "ExpiredToken":
                     LOG.error(message)
                     LOG.warning(
-                        f"Due to credentials error, we won't attempt to upload to S3."
+                        "Due to credentials error, we won't attempt to upload to S3."
                     )
                 else:
                     LOG.error(error)
