@@ -19,7 +19,7 @@
 Functions to build the ECS Service Definition
 """
 
-import re
+from ipaddress import IPv4Interface
 
 from troposphere import (
     Join,
@@ -31,6 +31,7 @@ from troposphere import (
     AWS_STACK_NAME,
 )
 from troposphere import Ref, Sub, GetAtt
+from troposphere import applicationautoscaling
 from troposphere.ec2 import EIP, SecurityGroup
 from troposphere.ec2 import SecurityGroupIngress
 from troposphere.ecs import LoadBalancer as EcsLoadBalancer
@@ -60,8 +61,6 @@ from troposphere.servicediscovery import (
     Instance as SdInstance,
 )
 
-from ipaddress import IPv4Interface
-
 from ecs_composex.common import add_parameters
 from ecs_composex.common import keyisset, LOG, NONALPHANUM
 from ecs_composex.common.cfn_conditions import USE_STACK_NAME_CON_T
@@ -174,6 +173,7 @@ class Task(object):
         """
         Init method
         """
+        self.definition = None
         add_service_roles(template)
         self.family_config = None
         self.containers = []
@@ -234,12 +234,15 @@ class Task(object):
         for service_config in ordered_containers_config:
             container = Container(
                 template,
-                service_config["config"].resource_name,
-                service_config["definition"],
+                service_config["config"].resource.logical_name,
+                service_config["config"].resource.definition,
                 service_config["config"],
             )
             import_secrets(
-                template, service_config["definition"], container.definition, settings
+                template,
+                service_config["config"].resource,
+                container.definition,
+                settings,
             )
             self.containers.append(container.definition)
             self.stack_parameters.update(container.stack_parameters)
@@ -254,7 +257,9 @@ class Task(object):
         """
         tasks_cpu = 0
         tasks_ram = 0
+        LOG.debug([container.Name for container in self.containers])
         for container in self.containers:
+            LOG.debug(container.title)
             if isinstance(container.Cpu, int):
                 tasks_cpu += container.Cpu
             if isinstance(container.Memory, int):
@@ -266,6 +271,7 @@ class Task(object):
         LOG.debug(f"CPU: {tasks_cpu}, RAM: {tasks_ram}")
         if tasks_cpu > 0 and tasks_ram > 0:
             cpu_ram = find_closest_fargate_configuration(tasks_cpu, tasks_ram, True)
+            LOG.debug(cpu_ram)
             self.stack_parameters.update({ecs_params.FARGATE_CPU_RAM_CONFIG_T: cpu_ram})
 
 
@@ -302,6 +308,34 @@ def generate_security_group_props(allowed_source, service_name):
     return props
 
 
+def define_tracking_target_configuration(target_scaling_config, config_key):
+    """
+    Function to create the configuration for target tracking scaling
+
+    :param dict target_scaling_config:
+    :param str config_key:
+    :return:
+    """
+    settings = {
+        "cpu": {"key": "cpu_target", "property": "ECSServiceAverageCPUUtilization"},
+        "memory": {
+            "key": "memory_target",
+            "property": "ECSServiceAverageMemoryUtilization",
+        },
+    }
+    if config_key not in settings.keys():
+        raise KeyError(config_key, "Is invalid. Expected one of", settings.keys())
+    return applicationautoscaling.TargetTrackingScalingPolicyConfiguration(
+        DisableScaleIn=target_scaling_config["disable_scale_in"],
+        ScaleInCooldown=target_scaling_config["scale_in_cooldown"],
+        ScaleOutCooldown=target_scaling_config["scale_out_cooldown"],
+        TargetValue=float(target_scaling_config[settings[config_key]["key"]]),
+        PredefinedMetricSpecification=applicationautoscaling.PredefinedMetricSpecification(
+            PredefinedMetricType=settings[config_key]["property"]
+        ),
+    )
+
+
 class Service(object):
     """
     Class representing the service from the Docker compose file and translate it into
@@ -338,6 +372,7 @@ class Service(object):
         self.resource_name = (
             config.resource_name if config.family_name is None else config.family_name
         )
+        self.scalable_target = None
         self.parameters = {
             vpc_params.VPC_ID_T: Ref(vpc_params.VPC_ID),
             PRIVATE_DNS_ZONE_ID.title: Ref(PRIVATE_DNS_ZONE_ID),
@@ -363,8 +398,58 @@ class Service(object):
         )
         self.define_service_ingress(settings)
         self.generate_service_definition(self.task.definition)
+        self.create_scalable_target()
         self.generate_service_template_outputs()
 
+    def create_scalable_target(self):
+        """
+        Method to automatically create a scalable target
+        """
+        LOG.debug(self.config.scaling_range)
+        if self.config.scaling_range:
+            self.scalable_target = applicationautoscaling.ScalableTarget(
+                ecs_params.SERVICE_SCALING_TARGET,
+                template=self.template,
+                MaxCapacity=self.config.scaling_range["max"],
+                MinCapacity=self.config.scaling_range["min"],
+                ScalableDimension="ecs:service:DesiredCount",
+                ServiceNamespace="ecs",
+                RoleARN=Sub(
+                    "arn:${AWS::Partition}:iam::${AWS::AccountId}:role/"
+                    "ecs.application-autoscaling.${AWS::URLSuffix}/"
+                    "AWSServiceRoleForApplicationAutoScaling_ECSService"
+                ),
+                ResourceId=Sub(
+                    f"service/${{{ecs_params.CLUSTER_NAME.title}}}/${{{self.ecs_service.title}.Name}}"
+                ),
+                SuspendedState=applicationautoscaling.SuspendedState(
+                    DynamicScalingInSuspended=False
+                ),
+            )
+        if self.scalable_target and self.config.target_scaling_config:
+            if keyisset("cpu_target", self.config.target_scaling_config):
+                applicationautoscaling.ScalingPolicy(
+                    "ServiceCpuTrackingPolicy",
+                    template=self.template,
+                    ScalingTargetId=Ref(self.scalable_target),
+                    PolicyName="CpuTrackingScalingPolicy",
+                    PolicyType="TargetTrackingScaling",
+                    TargetTrackingScalingPolicyConfiguration=define_tracking_target_configuration(
+                        self.config.target_scaling_config, "cpu"
+                    ),
+                )
+            if keyisset("memory_target", self.config.target_scaling_config):
+                applicationautoscaling.ScalingPolicy(
+                    "ServiceMemoryTrackingPolicy",
+                    template=self.template,
+                    ScalingTargetId=Ref(self.scalable_target),
+                    PolicyName="MemoryTrackingScalingPolicy",
+                    PolicyType="TargetTrackingScaling",
+                    TargetTrackingScalingPolicyConfiguration=define_tracking_target_configuration(
+                        self.config.target_scaling_config, "memory"
+                    ),
+                )
+
     def add_self_ingress(self, sg):
         """
         Method to allow communications internally to the group on set ports
@@ -491,10 +576,13 @@ class Service(object):
             Name=If(USE_HOSTNAME_CON_T, Ref(SERVICE_HOSTNAME), Ref(SERVICE_NAME)),
         )
         for port in self.config.ports:
+            used_port = port["published"]
+            if self.config.use_nlb() or self.config.use_alb():
+                used_port = port["target"]
             registry = ServiceRegistry(
-                f"ServiceRegistry{port['published']}",
+                f"ServiceRegistry{used_port}",
                 RegistryArn=GetAtt(sd_service, "Arn"),
-                Port=port["published"],
+                Port=used_port,
             )
             registries.append(registry)
             break
@@ -511,7 +599,7 @@ class Service(object):
             else:
                 title = (
                     f"From{flatten_ip(allowed_source['ipv4'])}"
-                    "To{port['published']}{port['protocol']}"
+                    f"To{port['published']}{port['protocol']}"
                 )
                 description = Sub(
                     f"Public {port['published']}{port['protocol']}"
@@ -528,7 +616,7 @@ class Service(object):
                 **props,
             )
 
-    def add_public_security_group_ingress(self, security_group):
+    def add_ext_sources_ingress(self, security_group):
         """
         Method to add ingress rules from external sources to a given Security Group (ie. ALB Security Group).
         If a list of IPs is found in the config['ext_sources'] part of the network section of configs for the service,
@@ -760,10 +848,10 @@ class Service(object):
                     "AWS_ALIAS_DNS_NAME": GetAtt(loadbalancer, "DNSName")
                 },
             )
-            if self.config.use_alb() and self.alb_sg:
-                self.add_public_security_group_ingress(self.alb_sg)
-            elif self.config.use_nlb():
-                self.add_public_security_group_ingress(SG_T)
+        if self.config.use_alb() and self.alb_sg:
+            self.add_ext_sources_ingress(self.alb_sg)
+        elif self.config.use_nlb():
+            self.add_ext_sources_ingress(SG_T)
         return loadbalancer
 
     def add_service_load_balancer(self, settings):
@@ -789,7 +877,7 @@ class Service(object):
                 EcsLoadBalancer(
                     TargetGroupArn=Ref(tgt),
                     ContainerPort=tgt.Port,
-                    ContainerName=NONALPHANUM.sub("", self.config.lb_service_name),
+                    ContainerName=self.config.resource.container_name,
                 )
             )
         return service_lbs, depends_on
@@ -844,6 +932,11 @@ class Service(object):
             self.service_attrs["DependsOn"] = (
                 service_lb[-1] if isinstance(service_lb[-1], list) else []
             )
+            self.service_attrs["HealthCheckGracePeriodSeconds"] = (
+                Ref(ecs_params.ELB_GRACE_PERIOD)
+                if self.service_attrs["LoadBalancers"]
+                else Ref(AWS_NO_VALUE)
+            )
             if self.config.use_alb() and self.config.aws_sources:
                 self.add_aws_sources(self.alb_sg)
         elif (
@@ -894,7 +987,6 @@ class Service(object):
                     "DAEMON",
                 ),
             ),
-            HealthCheckGracePeriodSeconds=Ref(AWS_NO_VALUE),
             PlacementStrategies=If(
                 ecs_conditions.USE_FARGATE_CON_T,
                 Ref(AWS_NO_VALUE),
