@@ -79,6 +79,7 @@ def initialize_service_template(service_name):
             ecs_params.FARGATE_CPU_RAM_CONFIG,
             ecs_params.SERVICE_NAME,
             ecs_params.LOG_GROUP_RETENTION,
+            ecs_params.ELB_GRACE_PERIOD,
         ],
     )
     service_tpl.add_condition(
@@ -101,7 +102,8 @@ def initialize_service_template(service_name):
         ecs_conditions.USE_CLUSTER_SG_CON_T, ecs_conditions.USE_CLUSTER_SG_CON
     )
     service_tpl.add_condition(
-        ecs_conditions.USE_FARGATE_CON_T, ecs_conditions.USE_FARGATE_CON,
+        ecs_conditions.USE_FARGATE_CON_T,
+        ecs_conditions.USE_FARGATE_CON,
     )
     service_tpl.add_condition(
         ecs_conditions.USE_CLUSTER_CAPACITY_PROVIDERS_CON_T,
@@ -212,7 +214,7 @@ def get_deploy_labels(service_definition):
             for item in svc_labels:
                 if not isinstance(item, str):
                     raise TypeError(
-                        f"When using a list for deploy labels, all labels must be of type string"
+                        "When using a list for deploy labels, all labels must be of type string"
                     )
                 parse_string_labels(labels, svc_labels)
         elif isinstance(svc_labels, dict):
@@ -231,7 +233,7 @@ def define_services_families(services):
     for service_name in services:
         labels = {}
         service = services[service_name]
-        svc_labels = get_deploy_labels(service)
+        svc_labels = get_deploy_labels(service.definition)
         LOG.debug(f"service {service_name} - labels {svc_labels}")
         labels.update(svc_labels)
         if not labels:
@@ -271,13 +273,14 @@ def handle_families_services(families, cluster_sg, settings):
         family_parameters = {}
         for service_name in family:
             service = settings.compose_content[ecs_params.RES_KEY][service_name]
-            if keyisset("deploy", service):
-                service["deploy"].update(get_deploy_labels(service))
-                LOG.debug(service["deploy"])
+            if keyisset("deploy", service.definition):
+                service.definition["deploy"].update(
+                    get_deploy_labels(service.definition)
+                )
+                LOG.debug(service.definition["deploy"])
             service_config = ServiceConfig(
-                settings.compose_content,
-                service_name,
                 service,
+                settings.compose_content,
                 family_name=family_resource_name,
             )
             family_service_configs[service_name] = {
