@@ -22,13 +22,10 @@ Main module to generate a full stack with VPC, Cluster, Compute, Services and al
 import re
 from importlib import import_module
 
-from troposphere import Ref, If, AWS_STACK_NAME, GetAtt
+from troposphere import Ref, AWS_STACK_NAME, GetAtt
 
 from ecs_composex.appmesh.appmesh_mesh import Mesh
-from ecs_composex.common import (
-    LOG,
-    add_parameters,
-)
+from ecs_composex.common import LOG, NONALPHANUM
 from ecs_composex.common import (
     build_template,
     keyisset,
@@ -50,7 +47,6 @@ from ecs_composex.compute.compute_params import (
 )
 from ecs_composex.compute.compute_stack import ComputeStack
 from ecs_composex.dns import add_parameters_and_conditions as dns_inputs, DnsSettings
-from ecs_composex.dns import dns_params, dns_conditions
 from ecs_composex.ecs import ServicesStack
 from ecs_composex.ecs import ecs_params
 from ecs_composex.ecs.ecs_cluster import add_ecs_cluster
@@ -135,10 +131,10 @@ def get_mod_class(module_name):
         res_module = import_module(composex_module_name)
         LOG.debug(res_module)
         try:
-            the_class = getattr(res_module, "XResource")
+            the_class = getattr(res_module, "XStack")
             return the_class
         except AttributeError:
-            LOG.info(f"No XResource class for {module_name} found - skipping")
+            LOG.info(f"No XStack class for {module_name} found - skipping")
             return None
     except ImportError as error:
         LOG.error(f"Failure to process the module {composex_module_name}")
@@ -184,7 +180,7 @@ def apply_x_configs_to_ecs(
 
 def apply_x_to_x_configs(root_template, settings):
     """
-    Function to iterate over each XResource and trigger cross-x resources configurations functions
+    Function to iterate over each XStack and trigger cross-x resources configurations functions
 
     :param troposphere.Template root_template: the ECS ComposeX root template
     :param ComposeXSettings settings: The execution settings
@@ -246,7 +242,9 @@ def add_x_resources(root_template, settings, vpc_stack=None):
                 LOG.info(f"Class for {res_type} not found")
             else:
                 xstack = xclass(
-                    res_type.strip(), settings=settings, Parameters=parameters,
+                    res_type.strip(),
+                    settings=settings,
+                    Parameters=parameters,
                 )
                 if vpc_stack and key in tcp_services:
                     xstack.get_from_vpc_stack(vpc_stack)
@@ -317,7 +315,10 @@ def generate_full_template(settings):
     :rtype: root_template, list
     """
     LOG.debug(settings)
-    root_stack = ComposeXStack(settings.name, stack_template=init_root_template())
+    root_stack_title = NONALPHANUM.sub("", settings.name.title())
+    root_stack = ComposeXStack(
+        root_stack_title, stack_template=init_root_template(), file_name=settings.name
+    )
     dns_inputs(root_stack)
     vpc_stack = add_vpc_to_root(root_stack, settings)
     dns_settings = DnsSettings(root_stack, settings, get_vpc_id(vpc_stack))
